@@ -6,6 +6,7 @@ from PyNite.BeamSegZ import BeamSegZ
 from PyNite.BeamSegY import BeamSegY
 import PyNite.FixedEndReactions
 from PyNite.LoadCombo import LoadCombo
+import warnings
 
 # %%
 class Member3D():
@@ -70,7 +71,7 @@ class Member3D():
         return ((jNode.X-iNode.X)**2+(jNode.Y-iNode.Y)**2+(jNode.Z-iNode.Z)**2)**0.5
 
 #%%
-    def AuxList(self):
+    def _aux_list(self):
         '''
         Builds lists of unreleased and released degree of freedom indices for the member.
 
@@ -100,7 +101,7 @@ class Member3D():
 
         # Partition the local stiffness matrix as 4 submatrices in
         # preparation for static condensation
-        k11, k12, k21, k22 = self.__Partition(self.__k_Unc())
+        k11, k12, k21, k22 = self._partition(self._k_unc())
                
         # Calculate the condensed local stiffness matrix
         k_Condensed = subtract(k11, matmul(matmul(k12, inv(k22)), k21))
@@ -119,7 +120,7 @@ class Member3D():
         return k_Condensed
 
 #%%
-    def __k_Unc(self):
+    def _k_unc(self):
         '''
         Returns the uncondensed local stiffness matrix for the member.
         '''
@@ -184,7 +185,7 @@ class Member3D():
 
         # Partition the geometric stiffness matrix as 4 submatrices in
         # preparation for static condensation
-        kg11, kg12, kg21, kg22 = self.__Partition(kg)
+        kg11, kg12, kg21, kg22 = self._partition(kg)
                
         # Calculate the condensed local geometric stiffness matrix
         # Note that a matrix of zeros cannot be inverted, so if P is 0 an error will occur
@@ -218,11 +219,11 @@ class Member3D():
         '''
         
         # Get the lists of unreleased and released degree of freedom indices
-        R1_indices, R2_indices = self.AuxList()
+        R1_indices, R2_indices = self._aux_list()
 
         # Partition the local stiffness matrix and local fixed end reaction vector
-        k11, k12, k21, k22 = self.__Partition(self.__k_Unc())
-        fer1, fer2 = self.__Partition(self.__fer_Unc(combo_name))
+        k11, k12, k21, k22 = self._partition(self._k_unc())
+        fer1, fer2 = self._partition(self._fer_unc(combo_name))
         
         # Calculate the condensed fixed end reaction vector
         ferCondensed = subtract(fer1, matmul(matmul(k12, inv(k22)), fer2))
@@ -240,7 +241,7 @@ class Member3D():
         return ferCondensed
     
 #%%
-    def __fer_Unc(self, combo_name='Combo 1'):
+    def _fer_unc(self, combo_name='Combo 1'):
         '''
         Returns the member's local fixed end reaction vector, ignoring the effects of end releases.
         Needed to apply the slope-deflection equation properly.
@@ -289,13 +290,13 @@ class Member3D():
         return fer
 
 #%%
-    def __Partition(self, unp_matrix):
+    def _partition(self, unp_matrix):
         '''
         Partitions a matrix into sub-matrices based on unreleased and released degree of freedom indices.
         '''
 
         # Create auxiliary lists of released/unreleased DOFs
-        R1_indices, R2_indices = self.AuxList()
+        R1_indices, R2_indices = self._aux_list()
 
         # Partition the matrix by slicing
         if unp_matrix.shape[1] == 1:
@@ -515,6 +516,10 @@ class Member3D():
 
 #%%
     def Shear(self, Direction, x, combo_name='Combo 1'):
+        warnings.warn('`Shear` will be replaced with `shear` in a future version of PyNite.', FutureWarning)
+        return self.shear(Direction, x, combo_name)
+
+    def shear(self, Direction, x, combo_name='Combo 1'):
         '''
         Returns the shear at a point along the member's length.
         
@@ -532,7 +537,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
 
         # Check which direction is of interest
@@ -562,6 +567,10 @@ class Member3D():
             
 #%%
     def MaxShear(self, Direction, combo_name='Combo 1'):
+        warnings.warn('`MaxShear` will be replaced with `max_shear` in a future version of PyNite.', FutureWarning)
+        return self.max_shear(Direction, combo_name)
+
+    def max_shear(self, Direction, combo_name='Combo 1'):
         '''
         Returns the maximum shear in the member for the given direction
         
@@ -577,7 +586,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
         
         if Direction == 'Fy':
@@ -586,9 +595,9 @@ class Member3D():
 
             for segment in self.SegmentsZ:
                 
-                if segment.MaxShear() > Vmax:
+                if segment.max_shear() > Vmax:
                     
-                    Vmax = segment.MaxShear()
+                    Vmax = segment.max_shear()
                     
         if Direction == 'Fz':
             
@@ -596,14 +605,18 @@ class Member3D():
 
             for segment in self.SegmentsY:
                 
-                if segment.MaxShear() > Vmax:
+                if segment.max_shear() > Vmax:
                     
-                    Vmax = segment.MaxShear()
+                    Vmax = segment.max_shear()
         
         return Vmax
     
 #%%
     def MinShear(self, Direction, combo_name='Combo 1'):
+        warnings.warn('`MinShear` will be replaced with `min_shear` in a future version of PyNite.', FutureWarning)
+        return self.min_shear(Direction, combo_name)
+
+    def min_shear(self, Direction, combo_name='Combo 1'):
         '''
         Returns the minimum shear in the member for the given direction
         
@@ -619,7 +632,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]   
         
         if Direction == 'Fy':
@@ -628,9 +641,9 @@ class Member3D():
 
             for segment in self.SegmentsZ:
                 
-                if segment.MinShear() < Vmin:
+                if segment.min_shear() < Vmin:
                     
-                    Vmin = segment.MinShear()
+                    Vmin = segment.min_shear()
                     
         if Direction == 'Fz':
             
@@ -638,14 +651,18 @@ class Member3D():
 
             for segment in self.SegmentsY:
                 
-                if segment.MinShear() < Vmin:
+                if segment.min_shear() < Vmin:
                     
-                    Vmin = segment.MinShear()
+                    Vmin = segment.min_shear()
         
         return Vmin
     
 #%%
     def PlotShear(self, Direction, combo_name='Combo 1'):
+        warnings.warn('`PlotShear` will be replaced with `plot_shear` in a future version of PyNite.', FutureWarning)
+        self.plot_shear(Direction, combo_name)
+
+    def plot_shear(self, Direction, combo_name='Combo 1'):
         '''
         Plots the shear diagram for the member
         
@@ -659,7 +676,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
         
         # Import 'pyplot' if not already done
@@ -687,6 +704,10 @@ class Member3D():
         
 #%%
     def Moment(self, Direction, x, combo_name='Combo 1'):
+        warnings.warn('`Moment` will be replaced with `moment` in a future version of PyNite.', FutureWarning)
+        return self.moment(Direction, x, combo_name)
+
+    def moment(self, Direction, x, combo_name='Combo 1'):
         '''
         Returns the moment at a point along the member's length
         
@@ -704,7 +725,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
         
         # Check which axis is of interest
@@ -715,12 +736,12 @@ class Member3D():
                 
                 if round(x,10) >= round(segment.x1,10) and round(x,10) < round(segment.x2,10):
                     
-                    return segment.Moment(x - segment.x1)
+                    return segment.moment(x - segment.x1)
                 
             if isclose(x, self.L()):
                 
                 lastIndex = len(self.SegmentsY) - 1
-                return self.SegmentsY[lastIndex].Moment(x - self.SegmentsY[lastIndex].x1)
+                return self.SegmentsY[lastIndex].moment(x - self.SegmentsY[lastIndex].x1)
                 
         elif Direction == 'Mz':
             
@@ -728,7 +749,7 @@ class Member3D():
                 
                 if round(x,10) >= round(segment.x1,10) and round(x,10) < round(segment.x2,10):
                     
-                    return segment.Moment(x - segment.x1)
+                    return segment.moment(x - segment.x1)
                 
             if isclose(x, self.L()):
                 
@@ -737,6 +758,10 @@ class Member3D():
             
 #%%
     def MaxMoment(self, Direction, combo_name='Combo 1'):
+        warnings.warn('`MaxMoment` will be replaced with `max_moment` in a future version of PyNite.', FutureWarning)
+        return self.max_moment(Direction, combo_name)
+
+    def max_moment(self, Direction, combo_name='Combo 1'):
         '''
         Returns the maximum moment in the member for the given direction.
         
@@ -752,33 +777,37 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
         
         if Direction == 'Mz':
             
-            Mmax = self.SegmentsZ[0].Moment(0)
+            Mmax = self.SegmentsZ[0].moment(0)
 
             for segment in self.SegmentsZ:
                 
-                if segment.MaxMoment() > Mmax:
+                if segment.max_moment() > Mmax:
                     
-                    Mmax = segment.MaxMoment()
+                    Mmax = segment.max_moment()
                     
         if Direction == 'My':
             
-            Mmax = self.SegmentsY[0].Moment(0)
+            Mmax = self.SegmentsY[0].moment(0)
 
             for segment in self.SegmentsY:
                 
-                if segment.MaxMoment() > Mmax:
+                if segment.max_moment() > Mmax:
                     
-                    Mmax = segment.MaxMoment()
+                    Mmax = segment.max_moment()
         
         return Mmax
 
 #%%
     def MinMoment(self, Direction, combo_name='Combo 1'):
+        warnings.warn('`MinMoment` will be replaced with `min_moment` in a future version of PyNite.', FutureWarning)
+        return self.min_moment(Direction, combo_name)
+
+    def min_moment(self, Direction, combo_name='Combo 1'):
         '''
         Returns the minimum moment in the member for the given direction
         
@@ -794,33 +823,37 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)   
+            self._segment_member(combo_name)   
             self.__solved_combo = self.LoadCombos[combo_name]
         
         if Direction == 'Mz':
             
-            Mmin = self.SegmentsZ[0].Moment(0)
+            Mmin = self.SegmentsZ[0].moment(0)
 
             for segment in self.SegmentsZ:
                 
-                if segment.MinMoment() < Mmin:
+                if segment.min_moment() < Mmin:
                     
-                    Mmin = segment.MinMoment()
+                    Mmin = segment.min_moment()
                     
         if Direction == 'My':
             
-            Mmin = self.SegmentsY[0].Moment(0)
+            Mmin = self.SegmentsY[0].moment(0)
 
             for segment in self.SegmentsY:
                 
-                if segment.MinMoment() < Mmin:
+                if segment.min_moment() < Mmin:
                     
-                    Mmin = segment.MinMoment()
+                    Mmin = segment.min_moment()
         
         return Mmin
 
 #%%
     def PlotMoment(self, Direction, combo_name='Combo 1'):
+        warnings.warn('`PlotMoment` will be replaced with `plot_moment` in a future version of PyNite.', FutureWarning)
+        self.plot_moment(Direction, combo_name)
+
+    def plot_moment(self, Direction, combo_name='Combo 1'):
         '''
         Plots the moment diagram for the member
         
@@ -834,7 +867,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
                 
         # Import 'pyplot' if not already done
@@ -853,7 +886,7 @@ class Member3D():
         for i in range(21):
             
             x.append(self.L()/20*i)
-            M.append(self.Moment(Direction, self.L()/20*i, combo_name))
+            M.append(self.moment(Direction, self.L()/20*i, combo_name))
 
         Member3D.__plt.plot(x, M)
         Member3D.__plt.ylabel('Moment')
@@ -863,6 +896,10 @@ class Member3D():
        
 #%%
     def Torsion(self, x, combo_name='Combo 1'):
+        warnings.warn('`Torsion` will be replaced with `torque` in a future version of PyNite.', FutureWarning)
+        return self.torque(x, combo_name)
+
+    def torque(self, x, combo_name='Combo 1'):
         '''
         Returns the torsional moment at a point along the member's length
         
@@ -876,7 +913,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
             
         # Check which segment 'x' falls on
@@ -890,6 +927,10 @@ class Member3D():
 
 #%%
     def MaxTorsion(self, combo_name='Combo 1'):
+        warnings.warn('`MaxTorsion` will be replaced with `max_torque` in a future version of PyNite.', FutureWarning)
+        return self.max_torque(combo_name)
+
+    def max_torque(self, combo_name='Combo 1'):
         '''
         Returns the maximum torsional moment in the member.
 
@@ -901,7 +942,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]       
         
         Tmax = self.SegmentsX[0].Torsion()   
@@ -916,6 +957,10 @@ class Member3D():
     
 #%%
     def MinTorsion(self, combo_name='Combo 1'):
+        warnings.warn('`MinTorsion` will be replaced with `min_torque` in a future version of PyNite.', FutureWarning)
+        return self.min_torque(combo_name)
+
+    def min_torque(self, combo_name='Combo 1'):
         '''
         Returns the minimum torsional moment in the member.
 
@@ -927,7 +972,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
         
         Tmin = self.SegmentsX[0].Torsion()
@@ -942,6 +987,10 @@ class Member3D():
 
 #%%
     def PlotTorsion(self, combo_name='Combo 1'):
+        warnings.warn('`PlotTorsion` will be replaced with `plot_torque` in a future version of PyNite.', FutureWarning)
+        self.plot_torque(combo_name)
+
+    def plot_torque(self, combo_name='Combo 1'):
         '''
         Plots the axial force diagram for the member.
         
@@ -953,7 +1002,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
         
         # Import 'pyplot' if not already done
@@ -981,6 +1030,10 @@ class Member3D():
         
 #%%
     def Axial(self, x, combo_name='Combo 1'):
+        warnings.warn('`Axial` will be replaced with `axial` in a future version of PyNite.', FutureWarning)
+        return self.axial(x, combo_name)
+
+    def axial(self, x, combo_name='Combo 1'):
         '''
         Returns the axial force at a point along the member's length.
         
@@ -994,20 +1047,24 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
             
         # Check which segment 'x' falls on
         for segment in self.SegmentsZ:
             if round(x, 10) >= round(segment.x1, 10) and round(x, 10) < round(segment.x2, 10):
-                return segment.Axial(x - segment.x1)
+                return segment.axial(x - segment.x1)
                 
             if isclose(x, self.L()):  
                 lastIndex = len(self.SegmentsZ) - 1
-                return self.SegmentsZ[lastIndex].Axial(x - self.SegmentsZ[lastIndex].x1)
+                return self.SegmentsZ[lastIndex].axial(x - self.SegmentsZ[lastIndex].x1)
 
 #%%
     def MaxAxial(self, combo_name='Combo 1'):
+        warnings.warn('`MaxAxial` will be replaced with `max_axial` in a future version of PyNite.', FutureWarning)
+        return self.max_axial(combo_name)
+
+    def max_axial(self, combo_name='Combo 1'):
         '''
         Returns the maximum axial force in the member
 
@@ -1019,21 +1076,25 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
         
-        Pmax = self.SegmentsZ[0].Axial(0)   
+        Pmax = self.SegmentsZ[0].axial(0)   
         
         for segment in self.SegmentsZ:
 
-            if segment.MaxAxial() > Pmax:
+            if segment.max_axial() > Pmax:
                     
-                Pmax = segment.MaxAxial()
+                Pmax = segment.max_axial()
         
         return Pmax
     
 #%%
     def MinAxial(self, combo_name='Combo 1'):
+        warnings.warn('`MinAxial` will be replaced with `min_axial` in a future version of PyNite.', FutureWarning)
+        return self.min_axial(combo_name)
+
+    def min_axial(self, combo_name='Combo 1'):
         '''
         Returns the minimum axial force in the member.
         
@@ -1045,21 +1106,25 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
         
-        Pmin = self.SegmentsZ[0].Axial(0)
+        Pmin = self.SegmentsZ[0].axial(0)
             
         for segment in self.SegmentsZ:
                 
-            if segment.MinAxial() < Pmin:
+            if segment.min_axial() < Pmin:
                     
-                Pmin = segment.MinAxial()
+                Pmin = segment.min_axial()
         
         return Pmin
     
 #%%
     def PlotAxial(self, combo_name='Combo 1'):
+        warnings.warn('`PlotAxial` will be replaced with `plot_axial` in a future version of PyNite.', FutureWarning)
+        self.plot_axial(combo_name)
+
+    def plot_axial(self, combo_name='Combo 1'):
         '''
         Plots the axial force diagram for the member.
         
@@ -1071,7 +1136,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
         
         # Import 'pyplot' if not already done
@@ -1089,7 +1154,7 @@ class Member3D():
         # Calculate the axial force diagram
         for i in range(21):
             x.append(self.L()/20*i)
-            P.append(self.Axial(self.L()/20*i, combo_name))
+            P.append(self.axial(self.L()/20*i, combo_name))
 
         Member3D.__plt.plot(x, P)
         Member3D.__plt.ylabel('Axial Force')
@@ -1099,6 +1164,10 @@ class Member3D():
                         
 #%%
     def Deflection(self, Direction, x, combo_name='Combo 1'):
+        warnings.warn('`Deflection` will be replaced with `deflection` in a future version of PyNite.', FutureWarning)
+        return self.deflection(Direction, x, combo_name)
+
+    def deflection(self, Direction, x, combo_name='Combo 1'):
         '''
         Returns the deflection at a point along the member's length.
         
@@ -1117,7 +1186,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
         
         # Check which axis is of interest
@@ -1163,6 +1232,10 @@ class Member3D():
 
 #%%
     def MaxDeflection(self, Direction, combo_name='Combo 1'):
+        warnings.warn('`MaxDeflection` will be replaced with `max_deflection` in a future version of PyNite.', FutureWarning)
+        return self.max_deflection(Direction, combo_name)
+
+    def max_deflection(self, Direction, combo_name='Combo 1'):
         '''
         Returns the maximum deflection in the member.
         
@@ -1176,7 +1249,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
         
         # Initialize the maximum deflection
@@ -1193,6 +1266,10 @@ class Member3D():
     
 #%%
     def MinDeflection(self, Direction, combo_name='Combo 1'):
+        warnings.warn('`MinDeflection` will be replaced with `min_deflection` in a future version of PyNite.', FutureWarning)
+        return self.min_deflection(Direction, combo_name)
+
+    def min_deflection(self, Direction, combo_name='Combo 1'):
         '''
         Returns the minimum deflection in the member.
         
@@ -1206,7 +1283,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
         
         # Initialize the minimum deflection
@@ -1223,6 +1300,10 @@ class Member3D():
               
 #%%
     def PlotDeflection(self, Direction, combo_name='Combo 1'):
+        warnings.warn('`PlotDeflection` will be replaced with `plot_deflection` in a future version of PyNite.', FutureWarning)
+        self.plot_deflection(Direction, combo_name)
+
+    def plot_deflection(self, Direction, combo_name='Combo 1'):
         '''
         Plots the deflection diagram for the member
         
@@ -1236,7 +1317,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
                 
         # Import 'pyplot' if not already done
@@ -1263,8 +1344,12 @@ class Member3D():
         Member3D.__plt.title('Member ' + self.Name + '\n' + combo_name)
         Member3D.__plt.show()
     
-#%%   
+#%%
     def RelativeDeflection(self, Direction, x, combo_name='Combo 1'):
+        warnings.warn('`RelativeDeflection` will be replaced with `rel_deflection` in a future version of PyNite.', FutureWarning)
+        return self.rel_deflection(Direction, x, combo_name)
+
+    def rel_deflection(self, Direction, x, combo_name='Combo 1'):
         '''
         Returns the relative deflection at a point along the member's length
         
@@ -1282,7 +1367,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
         
         d = self.d(self.LoadCombos[combo_name])
@@ -1322,6 +1407,10 @@ class Member3D():
 
 #%%
     def PlotRelativeDeflection(self, Direction, combo_name='Combo 1'):
+        warnings.warn('`PlotRelativeDeflection` will be replaced with `plot_rel_deflection` in a future version of PyNite.', FutureWarning)
+        self.plot_rel_deflection(Direction, combo_name)
+
+    def plot_rel_deflection(self, Direction, combo_name='Combo 1'):
         '''
         Plots the deflection diagram for the member
         
@@ -1335,7 +1424,7 @@ class Member3D():
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
-            self.SegmentMember(combo_name)
+            self._segment_member(combo_name)
             self.__solved_combo = self.LoadCombos[combo_name]
                 
         # Import 'pyplot' if not already done
@@ -1364,7 +1453,7 @@ class Member3D():
         
 #%%    
     # Divides the element up into mathematically continuous segments along each axis
-    def SegmentMember(self, combo_name='Combo 1'):
+    def _segment_member(self, combo_name='Combo 1'):
         
         # Get the member's length and stiffness properties
         L = self.L()
@@ -1425,7 +1514,7 @@ class Member3D():
         
         # Get the element local end forces, local fixed end reactions, and local displacements
         f = self.f(combo_name)           # Member local end force vector
-        fer = self.__fer_Unc(combo_name) # Member local fixed end reaction vector
+        fer = self._fer_unc(combo_name) # Member local fixed end reaction vector
         d = self.d(combo_name)           # Member local displacement vector
         
         # Get the local deflections and calculate the slope at the start of the member
